# Generated by Django 4.1.4 on 2022-12-15 10:01

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import netbox_dns.fields.address
import taggit.managers

from netbox_dns.models import RecordTypeChoices
from netbox_dns.utilities import arpa_to_prefix


def fqdn(record):
    if record.name == "@":
        return f"{record.zone.name}."
    else:
        return f"{record.name}.{record.zone.name}."


def address_from_name(record):
    prefix = arpa_to_prefix(fqdn(record))
    if prefix is not None:
        return prefix.ip

    return None


def update_ip_addresses(apps, schema_editor):
    Record = apps.get_model("netbox_dns", "Record")

    for record in Record.objects.filter(type=RecordTypeChoices.PTR):
        record.ip_address = address_from_name(record)
        record.save()

    for record in Record.objects.filter(
        type__in=(RecordTypeChoices.A, RecordTypeChoices.AAAA)
    ):
        record.ip_address = record.value
        record.save()


class Migration(migrations.Migration):

    dependencies = [
        ("extras", "0084_staging"),
        ("netbox_dns", "0020_netbox_3_4"),
    ]

    operations = [
        migrations.AddField(
            model_name="record",
            name="ip_address",
            field=netbox_dns.fields.address.AddressField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="record",
            name="tags",
            field=taggit.managers.TaggableManager(
                through="extras.TaggedItem", to="extras.Tag"
            ),
        ),
        migrations.AlterField(
            model_name="zone",
            name="soa_expire",
            field=models.PositiveIntegerField(
                validators=[django.core.validators.MinValueValidator(1)]
            ),
        ),
        migrations.AlterField(
            model_name="zone",
            name="soa_minimum",
            field=models.PositiveIntegerField(
                validators=[django.core.validators.MinValueValidator(1)]
            ),
        ),
        migrations.AlterField(
            model_name="zone",
            name="soa_mname",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                related_name="zones_soa",
                to="netbox_dns.nameserver",
            ),
        ),
        migrations.AlterField(
            model_name="zone",
            name="soa_refresh",
            field=models.PositiveIntegerField(
                validators=[django.core.validators.MinValueValidator(1)]
            ),
        ),
        migrations.AlterField(
            model_name="zone",
            name="soa_retry",
            field=models.PositiveIntegerField(
                validators=[django.core.validators.MinValueValidator(1)]
            ),
        ),
        migrations.AlterField(
            model_name="zone",
            name="soa_rname",
            field=models.CharField(max_length=255),
        ),
        migrations.AlterField(
            model_name="zone",
            name="soa_ttl",
            field=models.PositiveIntegerField(
                validators=[django.core.validators.MinValueValidator(1)]
            ),
        ),
        migrations.RunPython(update_ip_addresses),
    ]



# Generated by Django 3.2.9 on 2021-11-04 20:48

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        ("extras", "0062_clear_secrets_changelog"),
        ("netbox_dns", "0002_zone_default_ttl"),
    ]

    operations = [
        migrations.AddField(
            model_name="record",
            name="managed",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="zone",
            name="soa_expire",
            field=models.PositiveIntegerField(
                default=2592000,
                validators=[django.core.validators.MinValueValidator(1)],
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="zone",
            name="soa_minimum",
            field=models.PositiveIntegerField(
                default=3600, validators=[django.core.validators.MinValueValidator(1)]
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="zone",
            name="soa_mname",
            field=models.ForeignKey(
                default=1,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="zones_soa",
                to="netbox_dns.nameserver",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="zone",
            name="soa_refresh",
            field=models.PositiveIntegerField(
                default=172800, validators=[django.core.validators.MinValueValidator(1)]
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="zone",
            name="soa_retry",
            field=models.PositiveIntegerField(
                default=7200, validators=[django.core.validators.MinValueValidator(1)]
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="zone",
            name="soa_rname",
            field=models.CharField(default="hostmaster.example.com", max_length=255),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="zone",
            name="soa_serial",
            field=models.PositiveIntegerField(
                default=1,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(2147483647),
                ],
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="zone",
            name="soa_ttl",
            field=models.PositiveIntegerField(
                default=86400, validators=[django.core.validators.MinValueValidator(1)]
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="nameserver",
            name="tags",
            field=taggit.managers.TaggableManager(
                blank=True, through="extras.TaggedItem", to="extras.Tag"
            ),
        ),
        migrations.AlterField(
            model_name="record",
            name="tags",
            field=taggit.managers.TaggableManager(
                blank=True, through="extras.TaggedItem", to="extras.Tag"
            ),
        ),
        migrations.AlterField(
            model_name="zone",
            name="default_ttl",
            field=models.PositiveIntegerField(
                blank=True, validators=[django.core.validators.MinValueValidator(1)]
            ),
        ),
    ]



# Generated by Django 4.0.8 on 2022-10-26 18:55

from netaddr import IPNetwork, AddrFormatError

from django.db import migrations
import netbox_dns.fields.network


def update_zone_arpa_network(apps, schema_editor):
    Zone = apps.get_model("netbox_dns", "Zone")

    for zone in Zone.objects.filter(name__endswith=".arpa"):
        name = zone.name

        if name.endswith(".in-addr.arpa"):
            address = ".".join(reversed(name.replace(".in-addr.arpa", "").split(".")))
            mask = len(address.split(".")) * 8

            try:
                zone.arpa_network = IPNetwork(f"{address}/{mask}")
            except AddrFormatError:
                zone.arpa_network = None

        elif name.endswith("ip6.arpa"):
            address = "".join(reversed(name.replace(".ip6.arpa", "").split(".")))
            mask = len(address)
            address = address + "0" * (32 - mask)

            try:
                zone.arpa_network = IPNetwork(
                    f"{':'.join([(address[i:i+4]) for i in range(0, mask, 4)])}::/{mask*4}"
                )
            except AddrFormatError:
                zone.arpa_network = None

        zone.save()


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0017_alter_record_ttl"),
    ]

    operations = [
        migrations.AddField(
            model_name="zone",
            name="arpa_network",
            field=netbox_dns.fields.network.NetworkField(blank=True, null=True),
        ),
        migrations.RunPython(update_zone_arpa_network),
    ]



# Generated by Django 4.0.8 on 2022-10-18 07:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0016_cleanup_ptr_records"),
    ]

    operations = [
        migrations.AlterField(
            model_name="record",
            name="ttl",
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]



# Generated by Django 3.2.9 on 2021-11-26 16:54

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("netbox_dns", "0004_create_ptr_for_a_aaaa_records")]

    operations = [
        migrations.AddField(
            model_name="zone",
            name="soa_serial_auto",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="zone",
            name="soa_serial",
            field=models.BigIntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(4294967295),
                ],
            ),
        ),
    ]



# Generated by Django 3.2.9 on 2021-11-06 18:53

import logging

from django.db import migrations, models
from django.db.models import Q, deletion

from netbox_dns.models import RecordTypeChoices


def cleanup_disable_ptr(apps, schema_editor):
    logger = logging.getLogger("django")

    Record = apps.get_model("netbox_dns", "Record")

    unique_ptr_qs = Q(
        Q(disable_ptr=False),
        Q(Q(type=RecordTypeChoices.A) | Q(type=RecordTypeChoices.AAAA)),
    )

    for record in Record.objects.filter(unique_ptr_qs):
        logger.warning(
            "Disabling PTR generation for record %s:%s in zone %s",
            record.type,
            record.name,
            record.zone.name,
        )
        record.disable_ptr = True
        record.save()


class Migration(migrations.Migration):
    atomic = False

    dependencies = [
        ("netbox_dns", "0003_soa_managed_records"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="nameserver",
            options={"ordering": ("name",)},
        ),
        migrations.AlterModelOptions(
            name="record",
            options={"ordering": ("zone", "name", "type", "value")},
        ),
        migrations.AddField(
            model_name="record",
            name="disable_ptr",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="record",
            name="ptr_record",
            field=models.OneToOneField(
                blank=True,
                null=True,
                on_delete=deletion.SET_NULL,
                related_name="address_record",
                to="netbox_dns.record",
            ),
        ),
        migrations.RunPython(cleanup_disable_ptr),
        migrations.AddConstraint(
            model_name="record",
            constraint=models.UniqueConstraint(
                condition=Q(
                    Q(("disable_ptr", False)),
                    Q(
                        ("type", RecordTypeChoices.A),
                        ("type", RecordTypeChoices.AAAA),
                        _connector="OR",
                    ),
                ),
                fields=("type", "value"),
                name="unique_pointer_for_address",
            ),
        ),
    ]



import logging

from django.db import migrations
from django.db.models import Q

from netbox_dns.models import ZoneStatusChoices


def delete_ptr_records_for_inactive_zones(apps, schema_editor):
    logger = logging.getLogger("django")

    Record = apps.get_model("netbox_dns", "Record")

    for record in Record.objects.exclude(
        Q(Q(ptr_record__isnull=True) | Q(zone__status=ZoneStatusChoices.STATUS_ACTIVE))
    ):
        logger.warning(
            "Deleting PTR for record %s:%s in zone %s",
            record.type,
            record.name,
            record.zone.name,
        )
        record.ptr_record.delete()


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0014_add_view_description"),
        ("netbox_dns", "0015_add_record_status"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="record",
            options={"ordering": ("zone", "name", "type", "value", "status")},
        ),
        migrations.RunPython(delete_ptr_records_for_inactive_zones),
    ]



from django.db import models, transaction
from django.urls import reverse

from netbox.models import NetBoxModel
from netbox.search import SearchIndex, register_search


class Disk(NetBoxModel):
    vg_name = models.CharField(
        unique=False,
        max_length=255,
    )
    lv_name = models.CharField(
        unique=False,
        max_length=255,
    )
    size = models.PositiveIntegerField(
        verbose_name="size",
        null=True,
        blank=True,
    )
    description = models.CharField(
        max_length=200,
        blank=True,
    )

    clone_fields = ["vg_name", "lv_name", "size", "description"]

    def get_absolute_url(self):
        return reverse("plugins:netbox_disk:disk", kwargs={"pk": self.pk})

    def __str__(self):
        return f"{self.vg_name}.{self.lv_name} {str(self.size)}"

    class Meta:
        ordering = ("vg_name", "lv_name", "size")


@register_search
class DiskIndex(SearchIndex):
    model = Disk
    fields = (
        ("vg_name", 100),
        ("lv_name", 150),
        ("size", 200),
    )



from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0012_adjust_zone_and_record"),
        ("netbox_dns", "0013_add_nameserver_zone_record_description"),
    ]

    operations = [
        migrations.AddField(
            model_name="view",
            name="description",
            field=models.CharField(blank=True, max_length=200),
        ),
    ]



import django_filters
from django.db.models import Q

from netbox.filtersets import NetBoxModelFilterSet

from netbox_disk.models import Disk


class DiskFilter(NetBoxModelFilterSet):
    """Filter capabilities for Disk instances."""
    managed = django_filters.BooleanFilter()

    class Meta:
        model = Disk
        fields = ("vg_name", "lv_name", "size", "managed")

    def search(self, queryset, name, value):
        """Perform the filtered search."""
        if not value.strip():
            return queryset
        qs_filter = (
            Q(vg_name__icontains=value)
            | Q(lv_name__icontains=value)
            | Q(size__icontains=value)
        )
        return queryset.filter(qs_filter)


# Generated by Django 3.2.9 on 2021-11-26 07:01

from django.db import migrations
from netbox_dns.models import Record, RecordTypeChoices


def create_initial_ns_records(apps, schema_editor):
    Zone = apps.get_model("netbox_dns", "Zone")

    for zone in Zone.objects.all():
        nameservers = zone.nameservers.all()
        nameserver_names = [f'{ns.name.rstrip(".")}.' for ns in nameservers]

        ns_name = "@"
        ns_ttl = zone.default_ttl

        delete_ns = zone.record_set.filter(
            type=RecordTypeChoices.NS, managed=True
        ).exclude(value__in=nameserver_names)
        for record in delete_ns:
            record.delete()

        for ns in nameserver_names:
            Record.objects.update_or_create(
                zone_id=zone.pk,
                type=RecordTypeChoices.NS,
                name=ns_name,
                ttl=ns_ttl,
                value=ns,
                managed=True,
            )


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0007_alter_zone_soa_serial_auto"),
    ]

    operations = [
        migrations.RunPython(create_initial_ns_records),
    ]



from django import forms

from django.forms import (
    CharField,
    IntegerField,
    BooleanField,
    NullBooleanField,
)
from django.urls import reverse_lazy

from netbox.forms import (
    NetBoxModelBulkEditForm,
    NetBoxModelFilterSetForm,
    NetBoxModelImportForm,
    NetBoxModelForm,
)
from utilities.forms import (
    add_blank_choice,
    BulkEditNullBooleanSelect,
    DynamicModelMultipleChoiceField,
    TagFilterField,
    StaticSelect,
    CSVChoiceField,
    CSVModelChoiceField,
    DynamicModelChoiceField,
    APISelect,
    StaticSelectMultiple,
    add_blank_choice,
)

from netbox_disk.models import Disk


class DiskForm(NetBoxModelForm):
    """Form for creating a new Disk object."""

    class Meta:
        model = Disk

        fields = (
            "vg_name",
            "lv_name",
            "size",
            "description",
        )


class DiskFilterForm(NetBoxModelFilterSetForm):
    """Form for filtering Disk instances."""

    model = Disk

    vg_name = CharField(
        required=False,
        label="VG Name",
    )
    lv_name = CharField(
        required=False,
        label="LV Name",
    )
    size = IntegerField(
        required=False,
        label="Size (GB)",
    )


class DiskImportForm(NetBoxModelImportForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    class Meta:
        model = Disk

        fields = (
            "vg_name",
            "lv_name",
            "size",
            "description",
        )


class DiskBulkEditForm(NetBoxModelBulkEditForm):
    model = Disk

    vg_name = CharField(
        required=False,
        label="VG Name",
    )
    lv_name = CharField(
        required=False,
        label="LV Name",
    )
    size = IntegerField(
        required=False,
        label="Size (GB)",
    )
    description = CharField(max_length=200, required=False)

    fieldsets = (
        (
            None,
            ("vg_name", "lv_name", "size", "description"),
        ),
    )
    nullable_fields = ("description")


# Generated by Django 4.1.2 on 2022-11-19 15:55

from django.db import migrations, models
import utilities.json


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0019_update_ns_ttl"),
    ]

    operations = [
        migrations.AlterField(
            model_name="nameserver",
            name="custom_field_data",
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
        migrations.AlterField(
            model_name="record",
            name="custom_field_data",
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
        migrations.AlterField(
            model_name="view",
            name="custom_field_data",
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
        migrations.AlterField(
            model_name="zone",
            name="custom_field_data",
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
    ]



from extras.plugins import PluginConfig

__version__ = "0.0.7.6.5.5"


class DiskConfig(PluginConfig):
    name = "netbox_disk"
    verbose_name = "Netbox Disk"
    description = "Netbox Disk"
    min_version = "3.4.0"
    version = __version__
    author = "Tim Rhomberg"
    author_email = "timrhomberg@hotmail.cm.com"
    required_settings = []
    base_url = "netbox-disk"


config = DiskConfig


# Generated by Django 4.1.2 on 2022-11-30 15:35

import django.core.serializers.json
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import netbox_dns.fields.network
import taggit.managers


class Migration(migrations.Migration):

    replaces = [
        ("netbox_dns", "0001_initial"),
        ("netbox_dns", "0015_add_record_status"),
        ("netbox_dns", "0013_add_nameserver_zone_record_description"),
        ("netbox_dns", "0011_add_view_model"),
        ("netbox_dns", "0002_zone_default_ttl"),
        ("netbox_dns", "0003_soa_managed_records"),
        ("netbox_dns", "0004_create_ptr_for_a_aaaa_records"),
        ("netbox_dns", "0006_zone_soa_serial_auto"),
        ("netbox_dns", "0007_alter_zone_soa_serial_auto"),
        ("netbox_dns", "0005_update_ns_records"),
        ("netbox_dns", "0008_zone_status_names"),
        ("netbox_dns", "0009_netbox32"),
        ("netbox_dns", "0010_update_soa_records"),
        ("netbox_dns", "0012_adjust_zone_and_record"),
        ("netbox_dns", "0014_add_view_description"),
        ("netbox_dns", "0016_cleanup_ptr_records"),
        ("netbox_dns", "0017_alter_record_ttl"),
        ("netbox_dns", "0018_zone_arpa_network"),
        ("netbox_dns", "0019_update_ns_ttl"),
    ]

    initial = True

    dependencies = [
        ("extras", "0072_created_datetimefield"),
        ("extras", "0062_clear_secrets_changelog"),
        ("extras", "0073_journalentry_tags_custom_fields"),
        ("extras", "0059_exporttemplate_as_attachment"),
    ]

    operations = [
        migrations.CreateModel(
            name="NameServer",
            fields=[
                ("created", models.DateTimeField(auto_now_add=True, null=True)),
                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
                (
                    "custom_field_data",
                    models.JSONField(
                        blank=True,
                        default=dict,
                        encoder=django.core.serializers.json.DjangoJSONEncoder,
                    ),
                ),
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False
                    ),
                ),
                ("name", models.CharField(max_length=255, unique=True)),
                (
                    "tags",
                    taggit.managers.TaggableManager(
                        help_text="A comma-separated list of tags.",
                        through="extras.TaggedItem",
                        to="extras.Tag",
                        verbose_name="Tags",
                    ),
                ),
                ("description", models.CharField(blank=True, max_length=200)),
            ],
            options={
                "ordering": ("name",),
            },
        ),
        migrations.CreateModel(
            name="View",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False
                    ),
                ),
                ("created", models.DateTimeField(auto_now_add=True, null=True)),
                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
                (
                    "custom_field_data",
                    models.JSONField(
                        blank=True,
                        default=dict,
                        encoder=django.core.serializers.json.DjangoJSONEncoder,
                    ),
                ),
                ("name", models.CharField(max_length=255, unique=True)),
                (
                    "tags",
                    taggit.managers.TaggableManager(
                        help_text="A comma-separated list of tags.",
                        through="extras.TaggedItem",
                        to="extras.Tag",
                        verbose_name="Tags",
                    ),
                ),
                ("description", models.CharField(blank=True, max_length=200)),
            ],
            options={
                "ordering": ("name",),
            },
        ),
        migrations.CreateModel(
            name="Zone",
            fields=[
                ("created", models.DateTimeField(auto_now_add=True, null=True)),
                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
                (
                    "custom_field_data",
                    models.JSONField(
                        blank=True,
                        default=dict,
                        encoder=django.core.serializers.json.DjangoJSONEncoder,
                    ),
                ),
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False
                    ),
                ),
                ("name", models.CharField(max_length=255)),
                (
                    "status",
                    models.CharField(blank=True, default="active", max_length=50),
                ),
                (
                    "nameservers",
                    models.ManyToManyField(
                        blank=True, related_name="zones", to="netbox_dns.nameserver"
                    ),
                ),
                (
                    "tags",
                    taggit.managers.TaggableManager(
                        help_text="A comma-separated list of tags.",
                        through="extras.TaggedItem",
                        to="extras.Tag",
                        verbose_name="Tags",
                    ),
                ),
                ("description", models.CharField(blank=True, max_length=200)),
                (
                    "view",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="netbox_dns.view",
                    ),
                ),
                (
                    "default_ttl",
                    models.PositiveIntegerField(
                        blank=True,
                        validators=[django.core.validators.MinValueValidator(1)],
                    ),
                ),
                (
                    "soa_expire",
                    models.PositiveIntegerField(
                        default=2592000,
                        validators=[django.core.validators.MinValueValidator(1)],
                    ),
                ),
                (
                    "soa_minimum",
                    models.PositiveIntegerField(
                        default=3600,
                        validators=[django.core.validators.MinValueValidator(1)],
                    ),
                ),
                (
                    "soa_mname",
                    models.ForeignKey(
                        default=1,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="zones_soa",
                        to="netbox_dns.nameserver",
                    ),
                ),
                (
                    "soa_refresh",
                    models.PositiveIntegerField(
                        default=172800,
                        validators=[django.core.validators.MinValueValidator(1)],
                    ),
                ),
                (
                    "soa_retry",
                    models.PositiveIntegerField(
                        default=7200,
                        validators=[django.core.validators.MinValueValidator(1)],
                    ),
                ),
                (
                    "soa_rname",
                    models.CharField(default="hostmaster.example.com", max_length=255),
                ),
                (
                    "soa_serial",
                    models.BigIntegerField(
                        blank=True,
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(4294967295),
                        ],
                    ),
                ),
                (
                    "soa_ttl",
                    models.PositiveIntegerField(
                        default=86400,
                        validators=[django.core.validators.MinValueValidator(1)],
                    ),
                ),
                ("soa_serial_auto", models.BooleanField(default=True)),
                (
                    "arpa_network",
                    netbox_dns.fields.network.NetworkField(blank=True, null=True),
                ),
            ],
            options={
                "ordering": ("view", "name"),
                "unique_together": {("view", "name")},
            },
        ),
        migrations.CreateModel(
            name="Record",
            fields=[
                ("created", models.DateTimeField(auto_now_add=True, null=True)),
                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
                (
                    "custom_field_data",
                    models.JSONField(
                        blank=True,
                        default=dict,
                        encoder=django.core.serializers.json.DjangoJSONEncoder,
                    ),
                ),
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False
                    ),
                ),
                ("type", models.CharField(max_length=10)),
                ("name", models.CharField(max_length=255)),
                ("value", models.CharField(max_length=1000)),
                ("ttl", models.PositiveIntegerField(blank=True, null=True)),
                (
                    "tags",
                    taggit.managers.TaggableManager(
                        blank=True,
                        help_text="A comma-separated list of tags.",
                        through="extras.TaggedItem",
                        to="extras.Tag",
                        verbose_name="Tags",
                    ),
                ),
                (
                    "zone",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="netbox_dns.zone",
                    ),
                ),
                ("status", models.CharField(default="active", max_length=50)),
                ("description", models.CharField(blank=True, max_length=200)),
                ("managed", models.BooleanField(default=False)),
                ("disable_ptr", models.BooleanField(default=False)),
                (
                    "ptr_record",
                    models.OneToOneField(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="address_record",
                        to="netbox_dns.record",
                    ),
                ),
            ],
            options={
                "ordering": ("zone", "name", "type", "value", "status"),
            },
        ),
    ]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['netbox_disk',
 'netbox_disk.filters',
 'netbox_disk.forms',
 'netbox_disk.migrations',
 'netbox_disk.migrations.dns',
 'netbox_disk.tables',
 'netbox_disk.views']

package_data = \
{'': ['*'], 'netbox_disk': ['templates/netbox_disk/*']}

setup_kwargs = {
    'name': 'netbox-disk',
    'version': '0.0.7.6.5.5',
    'description': 'Netbox Disk Plugin',
    'long_description': '',
    'author': 'Tim Rhomberg',
    'author_email': 'timrhomberg@hotmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



# Generated by Django 4.0.4 on 2022-04-26 17:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0010_update_soa_records"),
        ("netbox_dns", "0011_add_view_model"),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name="record",
            name="unique_pointer_for_address",
        ),
    ]



from django.db import migrations


def update_ns_ttl(apps, schema_editor):
    Zone = apps.get_model("netbox_dns", "Zone")

    for zone in Zone.objects.all():
        for nameserver in zone.nameservers.all():
            nameserver.ttl = None


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0018_zone_arpa_network"),
    ]

    operations = [
        migrations.RunPython(update_ns_ttl),
    ]



from netbox.views import generic

from netbox_disk.filters import DiskFilter
from netbox_disk.forms import (
    DiskImportForm,
    DiskFilterForm,
    DiskForm,
    DiskBulkEditForm
)
from netbox_disk.models import Disk
from netbox_disk.tables import DiskTable


class DiskListView(generic.ObjectListView):
    queryset = Disk.objects.all()
    filterset = DiskFilter
    filterset_form = DiskFilterForm
    table = DiskTable


class DiskView(generic.ObjectView):
    """Display Disk details"""

    queryset = Disk.objects.all()


class DiskEditView(generic.ObjectEditView):
    """View for editing a Disk instance."""

    queryset = Disk.objects.all()
    form = DiskForm
    default_return_url = "plugins:netbox_disk:disk_list"


class DiskDeleteView(generic.ObjectDeleteView):
    queryset = Disk.objects.all()
    default_return_url = "plugins:netbox_disk:disk_list"


class DiskBulkImportView(generic.BulkImportView):
    queryset = Disk.objects.all()
    model_form = DiskImportForm
    table = DiskTable
    default_return_url = "plugins:netbox_disk:disk_list"


class DiskBulkEditView(generic.BulkEditView):
    queryset = Disk.objects.all()
    filterset = DiskFilter
    table = DiskTable
    form = DiskBulkEditForm


class DiskBulkDeleteView(generic.BulkDeleteView):
    queryset = Disk.objects.all()
    table = DiskTable



# Generated by Django 4.0.3 on 2022-07-28 15:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="record",
            name="status",
            field=models.CharField(default="active", max_length=50),
        ),
    ]
